import { ButtonOne, ButtonOneWithScroll } from "../../components/Buttons";
import { H4, H5 } from "../../components/Headings";
import { HPTimeline } from "../../components/HP-timeline";
import PreCyse from "../../components/precyse";
import { Section, Subesction } from "../../components/sections";
import { useNavigation } from "../../utils";
import { useTabNavigation } from "../../utils/TabNavigation";
import { HPconclusion } from "./Conclisuin";
import { HPFeedback } from "./Feedback";    
import  { HP3new } from "./HP svgs/hp3";
import {WholeMendelow} from "./HP svgs/mendelows";
import { StakeholderManagement } from "./HP svgs/stakeholder-management";
import { SWOTone } from "./HP svgs/swots";
import { HPUnderstanding } from "./HP svgs/understanding";

export function HPIntegrated(){
    const { goToPageWithTabAndScroll} = useNavigation();
    useTabNavigation();
    return(
        <Section title="Integrated Human Practices" id="Integrated Human Practices">
            <Subesction title="Framework" id="Integrated Human Practices1">
                <p>Our team has defined a framework for managing interactions with stakeholders during each step of the project:
                </p>
                <ol>
  <li> <b>Stakeholder Management Framework </b>- To identify stakeholders and define how potential stakeholders fit our project.</li>
  <li><b>Power-Interest Matrix </b>- According to Mendelow to identify and evaluate the priorities of potential stakeholders.</li>
  <li><b>SWOT analysis</b> - Assessment of the strengths, weaknesses, opportunities and threats of the various groups previously identified as potential stakeholders.</li>
  <li><b>AREA Framework</b> - To structure and optimize project-related decisions.</li>
  <li><b>Feedback-Cycle</b> - To structure interactions with stakeholders for efficient and informative design and maximization of potential.</li>
  <li><b>Third-Party Feedback Templates </b>- To introduce the stakeholders, summarize the interactions and implement the output in our project.</li>
  <li><b>Cycle of Reflection</b> - According to Gibbs demonstrate the response and implementation as a part of our feedback cycle.</li>
</ol>
            <div className="row align-items-center" style={{marginTop: "5vh", marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOneWithScroll text="Stakeholder Management" scrollId="stakeH" open="stakemamange" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll text="Mendelow Analysis" open="mendelow"  scrollId="mendelowH" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll text="SWOT analysis" scrollId="swotH" open="swot" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
            </div>
            <div className="row align-items-center" style={{marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOneWithScroll scrollId="areaH" text="Feedback Cycle" open="area" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="thirdH" text="Third Party Feedback" open="thirdparty" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="feedH" text="Cycle of Reflection" open="feedcycle" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="gibsonH" text="Gibbs' Cycle" open="gibson" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
            </div>
            <div className="col framecycletab" id="stakemamange" style={{display: "block"}}>
                <br/>
                <div className="align-items-center">
                <StakeholderManagement/>
                </div>  
                <H4 text="Stakeholder Management Framework" id="stakeH"/>
                <p>To clearly communicate to our stakeholders how they can support the <PreCyse/> project and the specific areas requiring 
                    their input, we developed a stakeholder management framework highlighting four key areas. Starting at the bottom right of the 
                    figure and moving clockwise, the first area needing feedback is <b>implementation</b>. It is crucial for our team to ensure that the project 
                    has all necessary components for realistic application in healthcare settings, focusing on the gene therapy treatment for cystic fibrosis.
                     This includes both the technical design and the appropriate business model to ensure successful implementation.
                </p>
                <p>The second key area is <b>sustainability and social impact.</b> We seek to understand how our project aligns with current healthcare initiatives and facilities in Germany and Europe, but also in the globally, and how it interacts with social efforts related to CF awareness and gene therapy strategies.
                </p>
                <p>Next, we want to shape the <b>public perception</b> of our project, which is based on synthetic biology to tackle a major healthcare challenge. We ask stakeholders about their knowledge and opinions on our gene therapeutic approach and its potential application to improve CF treatments.
                </p>
                <p>The final area involves <b>regulatory and safety considerations</b>. Given the stringent regulations governing healthcare in Germany, which vary by municipality, it is essential to consult with stakeholders familiar with these regulations to ensure our project complies with all necessary safety standards.
                </p>
            </div>
            <div className="col framecycletab" id="mendelow" style={{display: "none"}}>
                <H4 text="Power-Interest Matrix according to Mendelow" id="mendelowH"/>
                <p>Using the Mendelow Power-Interest Matrix, we classified the potential stakeholders associated with our project in terms of their power (the ability to provide important feedback on our project design and influence our project development) and interest in our project. The matrix consists of four quadrants arranged in descending order according to their priority level in the project:
                </p>
                <ul>
                <li>High Power, High Interest (Key Players)</li>
                <li>High Power, Low Interest (Keep Satisfied)</li>
                <li>Low Power, High Interest (Keep Informed)</li>
                <li>Low Power, Low Interest (Minimal Effort)</li>
                </ul>
                <p>This categorization helps to develop appropriate communication and management strategies for the different stakeholder groups and to ensure that their needs and influences are considered during the project.
                </p>
                <WholeMendelow/>
                <div className="row">
                    <div className="col">
                        <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-one", scrollToId: "keyplayersH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-1-aktuell.svg"/>
                        </a>
                    </div>
                    <div className="col">
                        <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-two", scrollToId: "keepH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-2.svg"/>
                        </a>
                    </div>
                    <div className="col">
                    <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-three", scrollToId: "informedH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-3-1.svg"/>
                        </a>
                    </div>
                    <div className="col">
                    <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-four", scrollToId: "minimalH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-4.svg"/>
                        </a>
                    </div>
                </div>
                {/* TABS */}
                <div className="mendelowtab" id="mendelow-one" style={{display: "none"}}>
                    <H4 text="Key Players" id="keyplayersH"/>
                    <H5 text="High Power, High Interest - Priority Level 4"/>
                        <p>
                        Close support and extensive feedback are necessary to successfully implement <PreCyse/>. 
                        Target groups include experts and physicians with expertise in gene therapy and treatment 
                        strategies for cystic fibrosis. The project has a reasonable, responsible, and future-oriented 
                        significance for the world. Furthermore, scientific-technological knowledge and biosafety are 
                        crucial. Collaboration with specialists in the field of gene therapy, cystic fibrosis, and different 
                        treatment strategies ensures the quality and effectiveness of the solutions developed.
                        </p>

                        <p><b>Scientific community and research institutions</b></p>
                        <p>
                        This group includes researchers, scientists, and research institutions specializing in gene editing 
                        and gene therapy. They have a high interest in the success of prime editing technology and have 
                        the power to significantly influence the project, be it through collaborations, scientific support, 
                        or critical reviews of the research results.
                        </p>

                        <p><b>Regulatory authorities (e.g. FDA, EMA)</b></p>
                        <p>
                        Regulatory agencies have both the power and the interest to ensure that gene therapy is safe and 
                        effective. They are crucial for the approval and authorization of the therapy for clinical use.
                        </p>


                </div>
                <div className="mendelowtab" id="mendelow-two" style={{display: "none"}}>
                    <H4 text=" Keep Satisfied" id="keepH"/>
                    <H5 text="High Power, Low Interest - Priority Level 3"/>
                    <p>
                    In order to successfully implement <PreCyse/>, all concerns must be fully considered, even if they 
                    may differ from the project interests. CF specialists, bioethics specialists, and regulatory experts 
                    provide important information. Their input is beneficial to the implementation of our project. 
                    These categories of experts help to ensure that the project is ethical and compliant with the law. 
                    Their expertise ensures that all relevant aspects are covered.
                    </p>

                    <p><b>Government and public health authorities</b></p>
                    <p>
                    Although these stakeholders have some interest in new therapies that improve population health, 
                    their day-to-day interest may not be specifically focused on the iGEM project. However, they have 
                    the power to influence the project through funding, political support, or regulatory action.
                    </p>

                    <p><b>Pharmaceutical companies and industries</b></p>
                    <p>
                    Large pharmaceutical companies have the power to significantly support the project through 
                    investment or strategic partnerships. However, their interest may be low for the time being until 
                    the project has proven that it is commercially promising.
                    </p>

                </div>
                <div className="mendelowtab" id="mendelow-three" style={{display: "none"}}>
                    <H4 text="Keep Informed" id="informedH"/>
                    <H5 text="KEEP INFORMED - Low Power, High Interest - Priority Level 2"/>
                    <p> <b>Potential users of <PreCyse/></b> </p>
                    <p>
                    are important for understanding the needs, even if their expertise 
                    may not be sufficient to solve all the problems that arise in the project. It is therefore important to 
                    keep them informed. These users include stakeholders as their needs coincide with the project. 
                    Their feedback can provide valuable insights. This collaboration helps to better tailor the project 
                    to user needs.
                    </p>
                    <p><b>Patients and patient organizations</b></p>
                    <p>
                    
                    Patients suffering from cystic fibrosis and the organizations that support them have a high interest in 
                    new therapies that could improve their quality of life. However, their power to influence the project 
                    is limited.
                    </p>
                    <p> <b>Academic community and students</b></p>
                    <p>
                    
                    This group includes universities, professors, and students who are interested in the latest research 
                    in gene therapy. Although they do not have the direct power to influence the project, they can 
                    support and promote the project through research and academic publications.
                    </p>

                </div>
                <div className="mendelowtab" id="mendelow-four" style={{display: "none"}}>
                    <H4 text="Minimal Effort" id="minimalH"/>
                    <H5 text="Low Power, Low Interest - Priority Level 1" />
                        <p><b>Stakeholders who are regularly monitored</b></p>
                        <p>
                        may not be interested in the project and do not provide feedback. However, this can change over time. 
                        Stakeholders in this category are involved in the right situation. For example, the public of Bielefeld is 
                        essential for understanding the background information about the awareness of gene therapy or Cystic Fibrosis. 
                        Their involvement occurs when it is relevant and other groups of people cannot meet their needs.
                        </p>

                        <p><b>General public of Bielefeld</b></p>
                        <p>
                        The public may have little interest and power in relation to the specific iGEM project. While a certain level 
                        of education and awareness of the topic is important, intensive involvement of this group is generally not necessary.
                        </p>

                        <p><b>Media</b></p>
                        <p>
                        The media may have an interest in scientific breakthroughs and new technologies, but they tend to have little 
                        power in terms of directly influencing the project. Nevertheless, strategic communication with the media can 
                        be important to manage public perception.
                        </p>

                    
                </div>
                
            </div>
            <div className="col framecycletab" id="swot" style={{display: "none"}}>
                <H4 text="SWOT Analyses" id="swotH"/>
                <p>A <b>SWOT</b> analysis is a strategic tool used to evaluate the <b>S</b>trengths, <b>W</b>eaknesses, <b>O</b>pportunities, and <b>T</b>hreats of an 
                organization. In the context of our Human Practice approach, this analysis helps us identify internal strengths and weaknesses of our project, such as 
                technical capabilities and resource limitations, while also examining external opportunities, like potential collaborations, and threats, such as regulatory 
                challenges or public perception. 
                </p>
                <SWOTone/>

            <div className="row align-items-center" style={{marginTop: "5vh", marginBottom: "1vh"}}>
                <div className="col">
                    <ButtonOne text="Patients" open="pats" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Industry" open="inds" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Academia" open="acs" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Healthcare" open="healths" openclass="subcycletab"></ButtonOne>
                </div>
                </div>
                <div className="row align-items-center" style={{ marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOne text="Government" open="govs" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="Community" open="comms" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="The Public" open="pubs" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="Business" open="busi" openclass="subcycletab"></ButtonOne>
                </div>
                </div>
                <div className="col subcycletab" id="pats" style={{display: "block"}}> 
                <H5 text="Patient Advocacy and Support Groups"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Strong support network for patients </td>
                            <td>Influential in policy advocacy </td>
                            <td>Personal connection to patient communities </td>
                        </tr>
                        <tr>
                            <td>Limited funding and resources </td>
                            <td>Potential resistance to new technologies </td>
                            <td>Dependence on donations and grants </td>
                        </tr>
                        <tr> 
                            <td>Increased patient engagement and support for new therapies </td>
                            <td>Advocacy can drive policy changes </td>
                            <td>Enhancing awareness and education </td>
                        </tr>
                        <tr> 
                            <td>Potential opposition from groups skeptical of new treatments </td>
                            <td>Misinformation or miscommunication about new therapies </td>
                            <td>Competing priorities among advocacy groups </td>
                        </tr>
                    </tbody>
                </table>

                </div>
                <div className="col subcycletab" id="inds" style={{display: "none"}}>
                <H5 text="Pharmaceutical Companies" />
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Resources for large-scale production and distribution </td>
                            <td>Experience with regulatory processes </td>
                            <td>Strong research and development capabilities </td>
                        </tr>
                        <tr>
                            <td>Focus on profitability may conflict with patient affordability </td>
                            <td>Long development timelines </td>
                            <td>Potential for high pricing </td>
                        </tr>
                        <tr> 
                            <td>Potential for developing new treatment modalities </td>
                            <td>Market expansion and competitive advantage </td>
                            <td>Partnerships with research institutions </td>
                        </tr>
                        <tr> 
                            <td>High cost and risk associated with new therapy development </td>
                            <td>Stringent regulatory and compliance requirements </td>
                            <td>Potential public backlash over high treatment costs </td>
                        </tr>
                    </tbody>
                </table>
                <H5 text="Bioengineering and Biotechnology Departments "/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Agile and innovative, can quickly adapt to new technologies </td>
                            <td>Focused on niche markets and cutting-edge solutions </td>
                            <td>Strong entrepreneurial spirit </td>
                        </tr>
                        <tr>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr> 
                            <td>Opportunity for rapid growth and partnership with larger firms </td>
                            <td>Potential to disrupt existing markets with innovative solutions </td>
                            <td>Opportunities for collaboration and acquisition </td>
                        </tr>
                        <tr> 
                            <td>High risk of failure and market volatility </td>
                            <td>Intense competition and fast-paced industry changes </td>
                            <td>Regulatory and market entry barriers </td>
                        </tr>
                    </tbody>
                </table>
    
                </div>
                <div className="col subcycletab" id="acs" style={{display: "none"}}>
                <H5 text="Genetic Research Institutions "/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Expertise in genetic disorders and advanced research capabilities </td>
                            <td>Access to state-of-the-art research facilities </td>
                            <td>Strong track record of innovation </td>
                        </tr>
                        <tr>
                            <td>May have limited practical experience with therapy delivery </td>
                            <td>Potential disconnect between research and clinical application </td>
                            <td>High operational costs </td>
                        </tr>
                        <tr> 
                            <td>Collaboration can lead to breakthroughs in gene editing </td>
                            <td>Potential for groundbreaking research and new discoveries </td>
                            <td>Collaborative research opportunities </td>
                        </tr>
                        <tr> 
                            <td>High competition for funding and research grants </td>
                            <td>Rapid technological changes requiring constant adaptation </td>
                            <td>Ethical and regulatory challenges </td>
                        </tr>
                    </tbody>
                </table>
                
                <H5 text="Universities and Academic Researchers "/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Strong research foundation and innovation capabilities </td>
                            <td>Access to a diverse pool of academic talent </td>
                            <td>Established research infrastructure </td>
                        </tr>
                        <tr>
                            <td>May have limited resources for commercialization </td>
                            <td>Limited industry connections </td>
                            <td>High competition for academic grants </td>
                        </tr>
                        <tr> 
                            <td>Potential for groundbreaking research and new discoveries </td>
                            <td>Collaboration with industry for applied research </td>
                            <td>Opportunities for interdisciplinary research </td>
                        </tr>
                        <tr> 
                            <td>Funding limitations and bureaucratic challenges </td>
                            <td>Intellectual property and technology transfer issues </td>
                            <td>Balancing academic research with practical applications </td>
                        </tr>
                    </tbody>
                </table>
               
                </div>

                <div className="col subcycletab" id="healths" style={{display: "none"}}>
                <H5 text="Pulmonologists and Respiratory Specialists"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Deep understanding of CF and its complications </td>
                            <td>Direct patient care experience </td>
                            <td>Established patient trust and rapport </td>
                        </tr>
                        <tr>
                            <td>May lack expertise in gene editing and new delivery systems </td>
                            <td>Limited time and resources for research involvement </td>
                            <td>Risk of slow adoption of new technologies </td>
                        </tr>
                        <tr> 
                            <td>Can provide valuable insights for therapy optimization </td>
                            <td>Opportunities for clinical trials and patient feedback </td>
                            <td>Enhanced treatment protocols through collaboration </td>
                        </tr>
                        <tr> 
                            <td>Resistance to adopt new and unproven therapies </td>
                            <td>Potential liability issues with new treatments </td>
                            <td>Competition from alternative therapies </td>
                        </tr>
                    </tbody>
                </table>
                <H5 text="Specialized Clinics and Hospitals"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Direct access to patient population </td>
                            <td>Ability to conduct clinical trials </td>
                            <td>Experienced medical staff and infrastructure </td>
                        </tr>
                        <tr>
                            <td>May lack expertise in gene therapy and new delivery systems </td>
                            <td>High operational costs </td>
                            <td>Potential liability and ethical concerns </td>
                        </tr>
                        <tr> 
                            <td>Clinical trials and real-world application of new therapies </td>
                            <td>Opportunities for improving patient care and outcomes </td>
                            <td>Collaboration with research institutions for therapy development </td>
                        </tr>
                        <tr> 
                            <td>High cost and complexity of integrating new therapies </td>
                            <td>Resistance from clinical staff to adopt new technologies </td>
                            <td>Competition for patients and clinical trial participation </td>
                        </tr>
                    </tbody>
                </table>
                <H5 text="Healthcare Networks"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Broad reach and influence </td>
                            <td>Ability to implement new therapies widely </td>
                            <td>Established relationships with patient communities </td>
                        </tr>
                        <tr>
                            <td>Variability in network capabilities and resources </td>
                            <td>Complex coordination required </td>
                            <td>Potential disparities in care quality </td>
                        </tr>
                        <tr> 
                            <td>Potential for large-scale impact on patient care </td>
                            <td>Leveraging network for large-scale clinical trials </td>
                            <td>Standardizing care across multiple facilities </td>
                        </tr>
                        <tr> 
                            <td>Organizational resistance to change </td>
                            <td>Economic pressures and budget constraints </td>
                            <td>Variability in regulatory compliance across regions </td>
                        </tr>
                    </tbody>
                </table>
                <H5 text=""/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr>
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr> 
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                        <tr> 
                            <td></td>
                            <td></td>
                            <td></td>
                        </tr>
                    </tbody>
                </table>
                </div>
                <div className="col subcycletab" id="govs" style={{display: "none"}}>
                <H5 text="Bioethics Committees "/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Ensure ethical standards are met </td>
                            <td>Provide guidance on complex issues </td>
                            <td>Enhance credibility and acceptance of new therapies </td>
                        </tr>
                        <tr>
                            <td>May be conservative and slow to approve new technologies </td>
                            <td>Potential for conflicting opinions within the committee </td>
                            <td>Limited authority to enforce decisions </td>
                        </tr>
                        <tr> 
                            <td>Establishing ethical frameworks for new therapies </td>
                            <td>Enhancing public trust through ethical oversight </td>
                            <td>Collaboration with regulatory agencies for comprehensive oversight </td>
                        </tr>
                        <tr> 
                            <td>Ethical dilemmas and public perception issues </td>
                            <td>Rapid advancements outpacing ethical guidelines </td>
                            <td>Misalignment with fast-paced technological advancements </td>
                        </tr>
                    </tbody>
                </table>
                <H5 text="Legal Experts"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Navigate complex legal landscapes </td>
                            <td>Ensure compliance with regulations </td>
                            <td>Expertise in healthcare law and genetic research regulations </td>
                        </tr>
                        <tr>
                            <td>High costs for legal services </td>
                            <td>Potential for lengthy legal processes </td>
                            <td>Risk of stifling innovation with overly cautious advice </td>
                        </tr>
                        <tr> 
                            <td>Development of comprehensive legal frameworks for new therapies </td>
                            <td>Protecting intellectual property and ensuring regulatory compliance </td>
                            <td>Advising on best practices for ethical and legal standards </td>
                        </tr>
                        <tr> 
                            <td>Legal challenges and liability issues </td>
                            <td>Rapidly changing legal environments and regulations </td>
                            <td>Potential for litigation and legal disputes </td>
                        </tr>
                    </tbody>
                </table>    
                </div>
                <div className="col subcycletab" id="comms" style={{display: "none"}}>
                <H5 text="Patient and Community Outreach Programs"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Increase awareness and education </td>
                            <td>Build public support </td>
                            <td>Foster connections between patients, researchers, and healthcare providers </td>
                        </tr>
                        <tr>
                            <td>Limited reach and resources </td>
                            <td>Potential misinformation </td>
                            <td>Dependence on volunteer efforts </td>
                        </tr>
                        <tr> 
                            <td>Enhanced public engagement and support for new therapies </td>
                            <td>Opportunities for community-driven advocacy </td>
                            <td>Raising funds and resources through public engagement </td>
                        </tr>
                        <tr> 
                            <td>Public skepticism and resistance to new technologies </td>
                            <td>Competing messages and priorities among various community groups </td>
                            <td>Miscommunication leading to misinformation </td>
                        </tr>
                    </tbody>
                </table>
                </div>
                <div className="col subcycletab" id="pubs" style={{display: "none"}}>
                <H5 text="Educational Institutions"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Educate future scientists and healthcare professionals </td>
                            <td>Promote research and innovation </td>
                            <td>Established infrastructure for education and research </td>
                        </tr>
                        <tr>
                            <td>Limited funding and resources for large-scale projects </td>
                            <td>Potential for academic bureaucracy </td>
                            <td>High competition for research grants </td>
                        </tr>
                        <tr> 
                            <td>Opportunity to foster new talent and innovation </td>
                            <td>Collaboration with industry and research institutions </td>
                            <td>Opportunities for interdisciplinary education and research </td>
                        </tr>
                        <tr> 
                            <td>Funding constraints and academic pressures </td>
                            <td>Balancing academic objectives with practical applications </td>
                            <td>Risk of brain drain to more lucrative industries </td>
                        </tr>
                    </tbody>
                </table>
                </div>
                <div className="col subcycletab" id="busi" style={{display: "none"}}>
                <H5 text="Funding Agencies and Venture Capitalists"/>
                <table cellPadding={10} cellSpacing={0} >
                    <thead>
                        <tr>
                            <th>Strengths</th>
                            <th>Weaknesses</th>
                            <th>Opportunities</th>
                            <th>Threats</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Provide crucial financial support </td>
                            <td>Drive innovation through investment </td>
                            <td>Extensive networks and industry connections </td>
                        </tr>
                        <tr>
                            <td>Focus on ROI may limit funding for high-risk projects </td>
                            <td>High competition for funding </td>
                            <td>Risk aversion may limit innovative but uncertain projects </td>
                        </tr>
                        <tr> 
                            <td>Potential for high returns and impact on healthcare </td>
                            <td>Supporting transformative technologies </td>
                            <td>Identifying and nurturing breakthrough technologies </td>
                        </tr>
                        <tr> 
                            <td>Economic downturns affecting investment capacity </td>
                            <td>Potential for high financial losses </td>
                            <td>Changes in economic and policy environments </td>
                        </tr>
                    </tbody>
                </table>    
                </div>
            </div>
            <div className="col framecycletab" id="thirdparty" style={{display: "none"}}>
               <H4 text="The Third-Party Feedback Template" id="thirdH"/>
                <p>To drive stakeholder interactions for the <PreCyse/> project, our team implemented the “Third-Party Feedback Template”. This template helps us introduce individuals to our stakeholders and demonstrate their significance to our project. There are three main sections in this template. First, we address the important question of who our stakeholders are, introducing their backgrounds and explaining why we reached out to them. Next, we summarize the conversations and knowledge exchanged during our interactions. Finally, we share our reflections from these stakeholder conversations and how these interactions have guided the next steps of our project.  </p>
                    <div className="col-4">
                        <div className="" >
                            <HPUnderstanding/> 
                        </div> 
                    </div>
                    <div className="col">
                        <div className="col understandingtab" id="under-reflection" style={{display: "block"}}>
                            <div><p>The reflection component of the template is essential in evaluating how stakeholder interactions have shaped the <PreCyse/> project. After summarizing conversations with stakeholders, we analyze the feedback they provided. This reflection process allows our team to carefully consider the insights shared and assess their relevance to our project's goals. By reflecting on this input, we gain a clearer understanding of how external perspectives align or differ from our initial assumptions, fostering an environment of continuous learning and improvement. This stage ensures that we approach the next steps with a deeper awareness of both our project’s impact and the expectations of our stakeholders.</p></div>
                        </div>
                        <div className="col understandingtab" id="under-responsibility" style={{display: "none"}}>
                            <div><p>Responsibility is embedded in how we engage with stakeholders and respond to the trust they place in our team. By thoughtfully selecting who we reach out to, we demonstrate responsibility in choosing the most relevant and impactful individuals for our project. Additionally, it is our duty to honor the contributions of stakeholders by effectively integrating their feedback into our decision-making process. The template allows us to document these contributions, emphasizing our commitment to not only listen but also act responsibly based on their input. Our responsibility extends to ensuring that stakeholder interests are respected and that their input is actively contributing to the ethical and sustainable development of the <PreCyse/> project.</p></div>
                        </div>
                        <div className="col understandingtab" id="under-responsive" style={{display: "none"}}>
                            <div><p>Responsiveness is about how we adapt and move forward based on the knowledge and perspectives shared by our stakeholders. After gathering feedback, we assess how it aligns with our project’s objectives and adjust our strategies accordingly. This ensures that stakeholder contributions are not only heard but also acted upon in a timely and constructive manner. The final section of the template emphasizes how these interactions have guided the future steps of the project. Being responsive is crucial for maintaining dynamic and evolving relationships with our stakeholders, demonstrating that we value their input and are willing to incorporate it into our ongoing development.</p></div>
                        </div>
                    </div>
            </div>
            <div className="col framecycletab" id="area" style={{display: "none"}}>
                <H4 text="AREA Framework" id="areaH"/>
                <p>The AREA Framework Analysis is a model that helps structure and optimize decision-making in complex projects, especially when multiple stakeholders are involved.
                </p>
                <div id="hp3-wrapper">
                    <div className="col">
                    <HP3new/>
                    </div>
                </div>
                <H5 text="Agenda"/>
                <p>
    The central goal of the <PreCyse/> project is to develop an innovative gene therapy solution for cystic fibrosis (CF) that is not only technically effective but also socially acceptable and ethically justifiable. The primary questions include:
</p>
<ul>
    <li>How can the project improve the lives of CF patients?</li>
    <li>How can the project ensure that the proposed therapy meets ethical and regulatory standards?</li>
    <li>How can the solution be integrated into current healthcare initiatives?</li>
    <li>How does the project influence, and how is it influenced by, the perceptions of stakeholders, particularly patients, regulatory authorities, and the scientific community?</li>
</ul>
<p>
    Here, the need is defined to develop a holistic understanding of the project’s impacts, considering both technological aspects and human perspectives.
</p>

                <H5 text="Research"/>
                <p>
    To gain a comprehensive understanding of the needs and expectations, the <PreCyse/> team employed various methods to collect data from relevant stakeholders, including:
</p>
<p>
    <b>Surveys of CF patients and their families:</b> These provided insights into the specific challenges and needs that CF patients face in daily life. Critical questions regarding safety, accessibility, and the long-term application of gene technology were addressed.
</p>
<p>
    <b>Expert consultations with researchers and physicians:</b> Scientists and doctors working in gene therapy provided essential technical feedback and helped assess the feasibility and effectiveness of the proposed therapy.
</p>
<p>
    <b>Regulatory authorities:</b> Feedback from agencies like the FDA and EMA played a central role in assessing safety requirements and regulatory challenges that need to be addressed before clinical application. This research phase was critical to ensuring that the technical solution aligned with patient needs and regulatory standards.
</p>

                <H5 text="Evaluation"/>
                <p>Based on the research phase results, a detailed assessment of the strengths, weaknesses, opportunities, and threats (SWOT analysis) was conducted (see above). The evaluation helped the team reflect on the gathered insights and focus on key challenges to ensure long-term feasibility and acceptance.
                </p>
                <H5 text="Agenda"/>
                <p>
    Based on the analysis, several measures were taken to ensure that the <PreCyse/> project is not only scientifically advanced but also socially and regulatorily acceptable:
</p>
<p>
    <b>Integrated feedback loops:</b> Stakeholders were continuously involved, and their feedback was directly incorporated into the adaptation and improvement of the project design. An example of this is the application of Gibbs' Reflection Cycle to ensure that all feedback is thoroughly analyzed and incorporated into future decisions.
</p>
<p>
    <b>Regulatory and ethical adjustments:</b> By working closely with regulatory authorities and ethics committees, measures were taken to ensure that the project complies with regulatory requirements and remains ethically justifiable.
</p>
<p>
    <b>Safety considerations:</b> The safety of the therapy was a key concern in stakeholder interactions. Specific safety protocols were developed to minimize risks for patients.
</p>
<p>
    <b>Public awareness:</b> To increase public awareness of the potential and safety of gene technologies, targeted communication measures were taken to address misunderstandings and improve acceptance of the technology.
</p>

            </div>
            <div className="col framecycletab" id="feedcycle" style={{display: "none"}}> 
                <H4 text="The Feedback Cycle of our IHP Approach" id="feedH"/>
                <p>To foster productive conversations and ensure our team maximizes each stakeholder interaction for the <PreCyse/> project, we developed a feedback cycle that outlines a structured approach for our meetings. The first step in our cycle involves listening to each stakeholder's experiences, personal stories, or insights. Our team then follows up by asking relevant questions to dive deeper into the shared information or to introduce new topics or directions in the conversation. Towards the end of the meeting, we ask clarifying questions and reiterate key points to ensure our understanding is accurate and that the stakeholder has no additional input. Finally, we explore new directions and ideas inspired by the stakeholder interaction, encouraging our team to pursue innovative and novel concepts.
                </p>
                <div>
                    <img src="https://static.igem.wiki/teams/5247/photos/hp/cycle2.svg"/>
                </div>

            </div>
            <div className="col framecycletab" id="gibson" style={{display: "none"}}> 
                <H4 text="Cycle of Reflections according to Gibbs" id="gibsonH"/>
                <p>For the <PreCyse/> project to impact the world, it needs to work with all types of stakeholders. Therefore, we are optimizing Gibbs' Reflection Cycle to demonstrate our inclusive response to the challenges we encountered during our iGEM journey. The cycle includes the impetus for our engagement, the unbiased two-way communication with stakeholders, our thorough analysis of the feedback and our actions to implement the stakeholder inputs into our project.
                </p>
                <div style={{height: "20%"}}>
                    <img src="https://static.igem.wiki/teams/5247/scientific-figures/gibbsreflection.svg" style={{height: "20%"}}/>
                </div>
                <p>
    <b>Impetus:</b> When developing a systematic approach to a recurring problem, it's easy to get distracted by multiple points of view. We need to prioritize quality over quantity. This section presents the successive impetus that drives the continuous implementation of Human Practices activities.
</p>
<p>
    <b>Two-way communication:</b> For our solution to be human-centered, the two-way communication method is to communicate to stakeholders the values we are incorporating into our project design. We make sure they understand the project clearly so that they can articulate their concerns and suggestions precisely.
</p>
<p>
    <b>Analysis:</b> The two-way communication with our stakeholders is carefully analyzed. In this section, stakeholder feedback is processed and turned into constructive guidance for project implementation, allowing us to consider what work should be prioritized to best address stakeholder concerns.
</p>
<p>
    <b>Implementation:</b> Implementation shows our measures for evaluating and refining the project. These actions are fully integrated into the project designs and other parts of our project to ensure that our project and activities are good, responsible and engaging for the world.
</p>
<p>
    In the areas of <b>Communication & Implementation</b>, <b>Necessity & Relevance</b>, <b>Science & Technology</b>, <b>Ethics & Regulation</b>, our Human Practice activities are conducted with X groups of stakeholders throughout our iGEM journey. In doing so, we explore the contexts that define projects, idealize solutions and evaluate outcomes for our human practice approach.
</p>

            </div>
            </Subesction>
            <Subesction title="Timeline" id="Integrated Human Practices2">
                <HPTimeline/>
            </Subesction>
            <Subesction title="Implementation & Feedback" id="Integrated Human Practices3">
                <HPFeedback/>
            </Subesction>

            <Subesction title="Conclusion" id="Integrated Human Practices4">
              <HPconclusion/>
            </Subesction>
        </Section>
    )
}