import { Section, Subesction } from "../components/sections";
import { PartTable } from "../components/Table";
import { useTabNavigation } from "../utils/TabNavigation";
import { BasicParts  } from "../data/parts";
import { H4 } from "../components/Headings";
import PartSources from "../sources/part-sources";

export function Parts() {
  useTabNavigation();
  let headcols = ["Part Name", "Registry Code", "Part Description", "length [bp]", "type"]
    return ( 
      <div className="col">
        <Section title="Description" id="Description">
          <Subesction title="Introduction" id="Description1">
            <p>In the context of cystic fibrosis, the F508del mutation represents a significant challenge for correction. The efficacy of current gene editing technologies hinges on the availability of precise tools to ensure the success of treatment strategies. In view of the above, we have developed a novel reporter system that is specifically tailored to the F508del mutation in the CFTR gene. The objective is to provide a high degree of comparability to the genomic context of this mutation, while maintaining ease of use. This system allows researchers to test and screen Prime Editors and various pegRNAs (prime editing guideRNAs), particularly in the context of the F508del mutation. By closely mimicking the genomic environment, it is believed that this tool will offer enhanced utility in the selection of optimal Prime Editing strategies. </p>
          </Subesction>
          <Subesction title="Prime Editor and pegRNA Testing" id="Description2">
            <p>The principal feature of the reporter system is its capacity to assess and quantify the efficacy of diverse Prime Editors, with a particular focus on pegRNAs. In its default state, the system expresses a non-functional GFP due to the disruption of the splice site. However, if a Prime Editor successfully restores the mutation to its correct form, the splice site is repaired and functional GFP is expressed, thereby allowing for fluorescent detection. This fluorescence serves as a reliable indicator of successful prime editing. </p>
            <p>The modified GFP sequence was cloned into the pDAS12124_PEAR-GFP-preedited plasmid, which was then transfected into HEK cells to initiate the pegRNA screening process. The capacity to observe the restoration of functional GFP provides a definitive indication of the efficacy of both the Prime Editor and the specific pegRNA variant under examination. Furthermore, the considerable degree of similarity between the reporter system and the actual genomic context of the CFTR mutation renders the screening process highly pertinent to the optimisation of specific applications. </p>
          </Subesction>
          <Subesction title="Conclusion" id="Description3">
            <p>This reporter system represents a substantial advancement in the study and correction of the CFTR F508del mutation. The design of the system allows for the straightforward screening of an array of Prime Editor and pegRNA constructs, while maintaining a high degree of comparability to the genomic context. By closely emulating the CFTR gene environment, particularly in the context of the F508del mutation, researchers are able to identify the most efficient pegRNAs and Prime Editors, offering a promising approach for developing more effective gene-editing treatments for cystic fibrosis. </p>
          </Subesction>
        </Section>

        <Section title="Characterization" id="Characterization">
          <Subesction title="Design and Functionality" id="Characterization1">
            <p>The reporter system has been designed with the specific intention of facilitating a more comparable genomic context for the F508del mutation, particularly for the purpose of testing the efficacy of different pegRNA variants and prime editors. The system provides a highly reliable platform for screening a variety of pegRNAs, thereby facilitating the identification of the most effective variant for correcting the F508del mutation</p>
            <p>The system is constructed around a plasmid structure, specifically pDAS12124_PEAR-GFP_GGTdel_edited, from which a modified version of GFP (Green Fluorescent Protein) has been derived. The green fluorescent protein (GFP) is composed of two exons, separated by a Vim gene intron in its natural state. In the absence of the intron, the GFP is expressed and fluoresces. However, the GFP sequence was modified to introduce a three-base-pair deletion, specifically in the junction between Exon 1 and the Vim gene intron. This deletion affects the last base of Exon 1 and the first two bases of the intron, effectively disrupting the splice site. As a result, the intron is no longer correctly spliced out, leading to the expression of a non-functional GFP that does not fluoresce. </p>
          </Subesction>
          <Subesction title="Adaptions for CFTR F508del mutation comparibility" id="Characterization2">
            <p>In addition to the introduction of the three-base-pair deletion, the intron sequence was further altered with the objective of enhancing the comparability of the system to the CFTR genomic context. Specifically, 27 base pairs were replaced downstream of the splice site with a sequence derived from the CFTR gene in the region of the F508del mutation. This modification guarantees that the gRNA spacer employed in our system is identical to the one found in the actual genomic context of the CFTR mutation. </p>
            <p>The only notable differences between the system and the genomic sequence are observed in the RTT (Reverse Transcript Template) and PBS (Primer Binding Site), which have been calibrated with silent mutations to maintain comparability in GC content with the native CFTR gene. These silent mutations do not affect the encoded protein but optimise the system's mimicry of the CFTR gene. </p>
            <img src="https://static.igem.wiki/teams/5247/new-basic-part/reporter-fragment.svg"/>
          </Subesction>
        </Section>

        <Section title="Experiments" id="Experiments">
          <Subesction title="Cloning" id="Experiments1">
            <p>The synthesised fragment was cloned into pDAS12124_PEAR-GFP-preedited plasmid using Gibson assembly, thus providing a vector with which the desired tests could be performed in HEK293 cells. The correctness of the cloning was determined by two methods: the correct size of the cloned plasmid was confirmed by gel electrophoresis, while the correct orientation and complete cloning were confirmed by Sanger sequencing. </p>
            <H4 text="Workflow "/>
            <p>The creation and validation of the CF-specific reporter system commenced with the selection and subsequent outgrowth of E. coli DH5α strains that contain the pDAS12124 plasmid. The initial stage of the process entails the isolation and purification of the pDAS12124 plasmid through the utilisation of conventional plasmid preparation methodologies, thereby ensuring its sterility and facilitating seamless downstream applications. Subsequent to the design of the CF-specific reporter system, the sequence was obtained from IDT. Upon its receipt, the fragment was amplified through polymerase chain reaction (PCR) to produce a sufficient quantity of material for the subsequent cloning phases. With the reporter system fragment ready, the pDAS12124_PEAR-GFP-preedited plasmid was digested using NheI and XhoI restriction enzymes. This cuts out the GFP cassette, creating the required entry point for the integration of the DNA fragment of the reporter system. To prevent the backbone from re-ligating, the sample is treated with phosphatase, ensuring the plasmid remains open for the upcoming Gibson assembly. </p>
            <p>Subsequently, a purification process is conducted to extract the plasmid backbone and concentrate the samples. This facilitates the integration of the amplified reporter system into the prepared pDAS12124_PEAR-GFP-preedited backbone, which is then subjected to the Gibson assembly process. This assembly process results in the creation of the novel pDAS12124_PEAR-GFP_GGTdel_edited plasmid, which incorporates the CF-specific reporter system. </p>
            <p>Subsequently, the pDAS12124_PEAR-GFP_GGTdel_edited plasmid is transformed into E. coli DH5α cells for propagation. To confirm the successful integration of the reporter fragment, colony PCR (cPCR) is performed on the transformed colonies. The positive colonies, identified by cPCR, are selected and grown in LBCm50 medium for further analysis.  </p>
            <p>The final validation step involves preparing the pDAS12124_PEAR-GFP_GGTdel_edited plasmid from the positive colonies and verifying the correct insertion of the reporter fragment using Sanger sequencing. This ensures the fragment is inserted in the correct orientation and that the CF-specific reporter system has been successfully constructed without any errors.  </p>
            <img src="https://static.igem.wiki/teams/5247/new-basic-part/cloning-of-pdas12124-pear-gfp-ggtdel-edited.svg]"/>
          </Subesction>
          <Subesction title="pegRNA Screening" id="Experiments2">
            <p>In connection with the optimisation of prime editing with regard to the F508del mutation, it was necessary to compare different pegRNAs, as their optimal structure always depends on the application context. We therefore designed and cloned 14 variants of pegRNAs for the target of the reporter system and then tested them on the reporter system using the PE2 system. </p>
            <p>For pegRNA screening, we co-transfected the HEK293 cells with our modified reporter plasmid, the pegRNA expressing plasmid and pCMV-PE2. We were then able to measure the fluorescence after 72 hours using FACS and evaluate which pegRNA showed the highest efficiency.  </p>
            {/* Bild */}
            <p>We also co-transfected the CFBE41o- with our modified reporter plasmid, the plasmid expressing pegRNA04 as well as pCMV-PE6c. As a result, we observed fluorescence, indicating successful editing of the reporter plasmid. The negative controls transfected with only one of the plasmids each showed no fluorescence, routing out other factors. This gave us validation, that our pegRNAs work not only in HEK, but also in epithelial cells that express CFTR F508del.  </p>
            {/* Bild */}
            <p>Based on the results, we were able to select 4 possible candidates and one negative example, whose attributes we then used to create pegRNAs for the CFTR target. The next step is to test these pegRNAs using CFBE41o- cells by again co-transfecting these with three plasmids: reporter plasmid, pegRNA expressing plasmid and pCMV-PE6c, and measuring fluorescence after 72 hours. </p>

          </Subesction>
          <Subesction title="Future Experiment: Nickase Assay" id="Experiments3">
           <p>In the next series of experiments, we would like to investigate various mutation candidates, in particular the possible SpuFz1 nickases (BBa_K5247101- BBa_K5247104) and various PlmCasx nickase variants (BBa_K5247105- BBa_K5247107), in more detail using the PE6c system. </p>
           {/* Bild Nikase */}
           <H4 text="nSpuFz1 "/>
           <p>The nSpuFz1 variants are expressed in yeast strain Pichia pastoris (SMD1163), which we obtained from Nils Berelsmann{/* [link zu HP-Timeline]. */} In advance, the corresponding genes were cloned into a suitable expression vector, pPIC9K, via Gibson Assembly to ensure efficient expression of the nickases. The cloning as well as the subsequent expression and purification of the nickases were carried out according to a detailed protocol[2] under the expert guidance of Hakan Soytürk[link zu HP timeline]. </p>
           <H4 text="nPlmCasX "/>
           <p>The nPlmCasX variants are expressed in E. coli strain BL21D3, which we obtained from AG Müller{/* [link zu HP-Timeline] */}. In advance, the corresponding genes were cloned into a suitable expression vector, pZMB1029, via Gibson Assembly to ensure efficient expression of the nickases. The cloning as well as the subsequent expression and purification of the nickases were carried out according to a detailed protocol[2]. </p>
           {/* Bild beide */}
           <p>After successful purification, the isolated nickases are comprehensively analyzed according to verify their activity and efficiency. These analyses will serve to evaluate the functionality and suitability of the nickases for specific applications in prime editing. Subsequently, detailed characterization experiments are planned to determine the properties of the nickases, if functional, including their specificity, editing activity and potential for use in precise gene editing procedures. </p>
           <p>Validation of the nickases will be performed in different cell lines to confirm their efficiency and reliability in a cellular context. These validation steps are crucial to further investigate the potential of Prime Guide for therapeutic applications. </p>
          </Subesction>
          
        </Section>
        <Section title="Parts Collection" id="Parts Collection">
          <Subesction title="Basic Parts" id="Parts Collection1">
            <PartTable cols={headcols} data={BasicParts}/>
          </Subesction>
        </Section>
        <Section title="References" id="References">
          <ol>
          <PartSources/>
          </ol>
        </Section>
      </div>
    );
  }
  